@@ -17,7 +17,7 @@
 ##############################################################
 
 martCheck = function(mart, biomart = NULL){
-    if( missing( mart ) || class( mart ) != 'Mart'){
+    if( missing(mart) || !inherits(mart,"Mart") ) {
         stop("You must provide a valid Mart object. To create a Mart object use the function: useMart.  Check ?useMart for more information.")
     }
     if(!is.null(biomart)){
@@ -44,7 +44,7 @@ bmRequest <- function(request, httr_config, verbose = FALSE){
     
     result <- httr::GET(request, config = httr_config, 
                         content_type("text/plain"),
-                        timeout(10))
+                        timeout(getOption("timeout", default = 60)))
     stop_for_status(result)
 
     result2 <- content(result, encoding = "UTF-8")
@@ -400,7 +400,7 @@ checkDataset <- function(dataset, mart) {
 
 ## Select a BioMart dataset             
 useDataset <- function(dataset, mart, verbose = FALSE){
-    if(missing(mart) || class(mart)!="Mart") 
+    if( missing(mart) || !inherits(mart,"Mart") )
         stop("No valid Mart object given, specify a Mart object with the attribute mart")
     
     if(missing(dataset)) {
@@ -471,7 +471,7 @@ filterOptions <- function(filter, mart){
 filterType <- function(filter, mart){
     if(missing(filter)) 
         stop("No filter given. Please specify the filter for which you want to retrieve the filter type")
-    if(class(filter)!="character")
+    if(!is.character(filter))
         stop("Filter argument should be of class character")
     martCheck(mart)
     type="unknown"
@@ -507,7 +507,7 @@ getBM <- function(attributes, filters = "", values = "", mart, curl = NULL,
         values = filters
         filters = names(filters)
     }
-    if(class(uniqueRows) != "logical")
+    if(!is.logical(uniqueRows))
         stop("Argument 'uniqueRows' must be a logical value, so either TRUE or FALSE")
     
     ## determine if we should use the results cache
@@ -733,7 +733,7 @@ getBMlist <- function(attributes, filters = "", values = "", mart, list.names =
 ####################
 
 exportFASTA <- function( sequences, file ) {
-    if( missing( sequences ) || class( sequences ) != "data.frame"){
+    if( missing( sequences ) || !is.data.frame( sequences )) {
         stop("No data.frame given to write FASTA.  The data.frame should be the output of the getSequence function.");
     }
     if( missing(file)){
